@@ -28,7 +28,7 @@ TZ = {
 	{ 'Africa/Gaborone', 'CAT-2' },
 	{ 'Africa/Harare', 'CAT-2' },
 	{ 'Africa/Johannesburg', 'SAST-2' },
-	{ 'Africa/Juba', 'EAT-3' },
+	{ 'Africa/Juba', 'CAT-2' },
 	{ 'Africa/Kampala', 'EAT-3' },
 	{ 'Africa/Khartoum', 'CAT-2' },
 	{ 'Africa/Kigali', 'CAT-2' },
@@ -216,7 +216,7 @@ TZ = {
 	{ 'Arctic/Longyearbyen', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Asia/Aden', '<+03>-3' },
 	{ 'Asia/Almaty', '<+06>-6' },
-	{ 'Asia/Amman', 'EET-2EEST,M3.5.4/24,M10.5.5/1' },
+	{ 'Asia/Amman', 'EET-2EEST,M2.5.4/24,M10.5.5/1' },
 	{ 'Asia/Anadyr', '<+12>-12' },
 	{ 'Asia/Aqtau', '<+05>-5' },
 	{ 'Asia/Aqtobe', '<+05>-5' },
@@ -239,8 +239,8 @@ TZ = {
 	{ 'Asia/Dubai', '<+04>-4' },
 	{ 'Asia/Dushanbe', '<+05>-5' },
 	{ 'Asia/Famagusta', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
-	{ 'Asia/Gaza', 'EET-2EEST,M3.4.4/48,M10.4.4/49' },
-	{ 'Asia/Hebron', 'EET-2EEST,M3.4.4/48,M10.4.4/49' },
+	{ 'Asia/Gaza', 'EET-2EEST,M3.4.4/48,M10.5.5/1' },
+	{ 'Asia/Hebron', 'EET-2EEST,M3.4.4/48,M10.5.5/1' },
 	{ 'Asia/Ho Chi Minh', '<+07>-7' },
 	{ 'Asia/Hong Kong', 'HKT-8' },
 	{ 'Asia/Hovd', '<+07>-7' },
@@ -416,14 +416,13 @@ TZ = {
 	{ 'Indian/Mauritius', '<+04>-4' },
 	{ 'Indian/Mayotte', 'EAT-3' },
 	{ 'Indian/Reunion', '<+04>-4' },
-	{ 'Pacific/Apia', '<+13>-13<+14>,M9.5.0/3,M4.1.0/4' },
+	{ 'Pacific/Apia', '<+13>-13' },
 	{ 'Pacific/Auckland', 'NZST-12NZDT,M9.5.0,M4.1.0/3' },
 	{ 'Pacific/Bougainville', '<+11>-11' },
 	{ 'Pacific/Chatham', '<+1245>-12:45<+1345>,M9.5.0/2:45,M4.1.0/3:45' },
 	{ 'Pacific/Chuuk', '<+10>-10' },
 	{ 'Pacific/Easter', '<-06>6<-05>,M9.1.6/22,M4.1.6/22' },
 	{ 'Pacific/Efate', '<+11>-11' },
-	{ 'Pacific/Enderbury', '<+13>-13' },
 	{ 'Pacific/Fakaofo', '<+13>-13' },
 	{ 'Pacific/Fiji', '<+12>-12<+13>,M11.2.0,M1.2.3/99' },
 	{ 'Pacific/Funafuti', '<+12>-12' },
@@ -432,6 +431,7 @@ TZ = {
 	{ 'Pacific/Guadalcanal', '<+11>-11' },
 	{ 'Pacific/Guam', 'ChST-10' },
 	{ 'Pacific/Honolulu', 'HST10' },
+	{ 'Pacific/Kanton', '<+13>-13' },
 	{ 'Pacific/Kiritimati', '<+14>-14' },
 	{ 'Pacific/Kosrae', '<+11>-11' },
 	{ 'Pacific/Kwajalein', '<+12>-12' },
